@@ -29,7 +29,9 @@ typedef unsigned short int us_int;
 extern volatile sig_atomic_t	quit;
 extern int			debug;
 extern int			mimes_size;
+#ifdef __OpenBSD__
 extern int			fdbsdauth[2];
+#endif
 extern char			*mimes;
 extern char			logn[1024];
 
@@ -100,8 +102,9 @@ struct cfg {
 	char	serveradmin[1024];	/* Server Admin Email */
 	char	serverroot[1024];	/* Full Path to server root */
 	char	servermimes[1024];	/* Filename for mime types */
-	char	logserver[1024];	/* Filename for server log */
+	int	logpid_flag;		/* Pid log Flag */
 	char	logpid[1024];		/* Filename for server pid */
+	int	logaccess_flag;		/* Access log Flag */
 	char	logaccess[1024];	/* Filename for access log */
 	char	docroot[1024];		/* Full Path to server document root */
 	char	docindex[1024];		/* Filename for index documents */
@@ -109,7 +112,9 @@ struct cfg {
 	char	htaccess[1024];		/* Filename for basic auth */
 	char	htpasswd[1024];		/* Full Filename for basic auth users */
 	char	file[1024];		/* Full Filename for config file */
+#ifdef __OpenBSD__
 	int	bsdauth;		/* BSD auth Flag */
+#endif
 	int	ssl;			/* SSL Flag */
 	int	sslport;		/* SSL Listener Port */
 	char	sslportc[8];		/* SSL Listener Port in char */
