@@ -23,9 +23,11 @@
 #include <fcntl.h>
 #include <openssl/ssl.h>
 #include <signal.h>
+#include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <syslog.h>
 #include <time.h>
 #include <unistd.h>
 
@@ -330,8 +332,8 @@ http_proc(const char *header, char *body, const int hr, const int blen,
 	if (rh->rp_status == 200 && rh->x_cgi == 1) {
 		/* fork child for nhttpd */
 		if ((cpid = fork()) == -1) {
-			flogd(config.logserver, "[error] can't fork nhttpd "
-			    "child for cgi: fork: %s\n", strerror(errno));
+			syslog(LOG_ERR, "can't fork child for cgi: fork: %s",
+			    strerror(errno));
 			free(rh);
 			return (-1);
 		}
@@ -353,8 +355,8 @@ http_proc(const char *header, char *body, const int hr, const int blen,
 
 		/* fork child for cgi */
 		if ((cpid = fork()) == -1) {
-			flogd(config.logserver, "[error] can't fork cgi: "
-			    "fork: %s\n", strerror(errno));
+			syslog(LOG_ERR, "can't fork cgi: fork: %s",
+			    strerror(errno));
 			exit(1);
 		}
 
@@ -511,8 +513,8 @@ http_proc(const char *header, char *body, const int hr, const int blen,
 		r = -1;
 		for (i = 0; i < sizeof(buf); i++) {
 			if ((rp = sys_read(fds2[0], ch, 1)) < 1) {
-				flogd(config.logserver, "[error] %s "
-				    "sent a bad cgi header\n", rh->rq_uri);
+				syslog(LOG_ERR, "%s sent a bad cgi header",
+				    rh->rq_uri);
 				break;
 			}
 			buf[i] = ch[0];
@@ -527,8 +529,8 @@ http_proc(const char *header, char *body, const int hr, const int blen,
 				}
 				len = rh->rp_hsize + strlen(buf) + 1;
 				if ((x = malloc(len)) == NULL) {
-					flogd(config.logserver,
-					    "[error] can't malloc memory for "
+					syslog(LOG_ERR,
+					    "can't malloc memory for "
 					    "cgi header: malloc: %s",
 					    strerror(errno));
 					break;
@@ -639,7 +641,7 @@ http_proc(const char *header, char *body, const int hr, const int blen,
 	if (rh->rp_status == 200 && rh->x_idx == 1) {
 		/* fork child for nhttpd */
 		if ((cpid = fork()) == -1) {
-			flogd(config.logserver, "[error] can't fork nhttpd "
+			syslog(LOG_ERR, "can't fork "
 			    "child for dirlist: fork: %s\n", strerror(errno));
 			free(rh);
 			return (-1);
@@ -828,7 +830,8 @@ http_proc(const char *header, char *body, const int hr, const int blen,
 	}
 
 	/* access log write */
-	flog(logn, "%s %s\n", log_1, log_2);
+	if (config.logaccess_flag)
+		flog(logn, "%s %s\n", log_1, log_2);
 
 	/* nhttpd child exits */
 	if (x_fork)
@@ -1627,20 +1630,25 @@ http_header(const char *header_data, const char *force_status,
 			    sizeof(h->rq_fv_usr));
 			strcuts(acc_pw, acc_userpw, ':', '\0', sizeof(acc_pw));
 			/* authenticate */
+#ifdef __OpenBSD__
 			if (config.bsdauth) {
 				if ((r = sys_access_bsdauth(h->rq_fv_usr,
 				    acc_pw)) != 1)
 					/* failed */
 					h->x_aut = 0;
 			} else {
+#endif
 				if ((r = sys_access_auth(h->rq_fv_usr,
 				    acc_pw)) != 1)
 					/* failed */
 					h->x_aut = 0;
+#ifdef __OpenBSD__
 			}
+#endif
 		}
 		/* authenticate option is not set or failed */
 		if (!h->x_aut) {
+#ifdef __OpenBSD__
 			/* no unsecure bsd auth permitted */
 			if (config.bsdauth == 1 && !c[sfd].ssl) {
 				/* 403 */
@@ -1650,6 +1658,7 @@ http_header(const char *header_data, const char *force_status,
 				    sizeof(h->rp_fv_cte));
 				h->rp_status = 403;
 			} else {
+#endif
 				/* get access realm */
 				if (fparse(h->rp_fv_auw, "realm", acc_file,
 				    sizeof(h->rp_fv_auw)) == -1) {
@@ -1663,7 +1672,9 @@ http_header(const char *header_data, const char *force_status,
 				    sizeof(h->rp_fv_cte)); 
 				h->x_cgi = 0;
 				h->rp_status = 401;
+#ifdef __OpenBSD__
 			}
+#endif
 		}
 	}
 
