@@ -32,9 +32,11 @@
 #include <openssl/ssl.h>
 #include <pwd.h>
 #include <signal.h>
+#include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <syslog.h>
 #include <time.h>
 #include <unistd.h> 
 
@@ -60,7 +62,9 @@ static const char	*configfile = "/var/nostromo/conf/nhttpd.conf";
 volatile sig_atomic_t	quit = 0;
 int			debug = 0;
 int			mimes_size;
+#ifdef __OpenBSD__
 int			fdbsdauth[2];
+#endif
 char			*mimes;
 char			logn[1024];
 
@@ -105,7 +109,7 @@ const char *http_fn_auw		= "WWW-Authenticate:";
 const char *http_fn_ran		= "Range:";
 const char *http_fn_rac		= "Content-Range:";
 const char *http_fn_aen		= "Accept-Encoding:";
-const char *http_fv_srv		= "nostromo 1.8.8";
+const char *http_fv_srv		= "nostromo 1.9";
 const char *http_fv_pro		= "HTTP/1.1";
 const char *http_fv_cgi		= "CGI/1.1";
 const char *http_fv_teg		= "chunked";
@@ -192,8 +196,7 @@ sig_handler(const int sig)
 		/* ignore */
 		break;
 	default:
-		flogd(config.logserver, "[info] unhandled signal %i, ignored\n",
-		    sig);
+		syslog(LOG_INFO, "unhandled signal %i, ignored", sig);
 		break;
 	}
 }
@@ -362,7 +365,8 @@ send_file(const int sfd, const int hr)
 
 	/* file sent, write access log, cleanup */
 	if (c[sfd].wred < 1 || s < 0 || c[sfd].pfds[hr] == 0) {
-		http_alog(sfd, hr);
+		if (config.logaccess_flag)
+			http_alog(sfd, hr);
 		close(c[sfd].pfdn[hr]);
 		c[sfd].pfdo--;
 		c[sfd].wred = 0;
@@ -389,13 +393,18 @@ main(int argc, char *argv[])
 	int			sdlis1, sdlis2, sdlis3, sdlis4;
 	int			sdmax, sdnew, sdnow, sdlim;
 	int			i, j, k, r, s, ch, rd, rt, wr, post, size;
-	int			fd, erro, pid, opt_c, opt_r, opt_4, opt_6;
+	int			fd, erro, opt_c, opt_r, opt_4, opt_6;
+#ifdef __OpenBSD__
+	int			pid;
+#endif
 	char			in[HDN * HDS + 1], tmp[HDS + 1];
 	char			header[HDN][HDS + 1];
 	char			*b, *h, *offset, *body = NULL;
 	extern char		**environ;
 	struct passwd		*pwd = NULL;
+#ifdef __OpenBSD__
 	struct group		*grp = NULL;
+#endif
 	struct stat		st;
 	struct hostent		*host;
 	struct sockaddr_in	sa, ca;
@@ -495,22 +504,6 @@ main(int argc, char *argv[])
 		fprintf(stderr, "Missing <servermimes> in config file.\n");
 		r = -1;
 	}
-	if (fparse(config.logserver, "logserver", config.file,
-	    sizeof(config.logserver)) == -1) {
-		fprintf(stderr, "Missing <logserver> in config file.\n");
-		r = -1;
-	}
-	if (fparse(config.logpid, "logpid", config.file,
-	    sizeof(config.logpid)) == -1) {
-		fprintf(stderr, "Missing <logpid> in config file.\n");
-		r = -1;
-	}
-	if (fparse(config.logaccess, "logaccess", config.file,
-	    sizeof(config.logaccess)) == -1) {
-		fprintf(stderr, "Missing <logaccess> in config file.\n");
-		r = -1;
-	} else
-		strlcpy(logn, config.logaccess, sizeof(logn));
 	if (fparse(config.docroot, "docroot", config.file,
 	    sizeof(config.docroot)) == -1) {
 		fprintf(stderr, "Missing <docroot> in config file.\n");
@@ -523,6 +516,19 @@ main(int argc, char *argv[])
 	}
 
 	/* optional configuration parameters */
+	if (fparse(config.logpid, "logpid", config.file,
+	    sizeof(config.logpid)) == -1) {
+		config.logpid_flag = 0;
+	} else {
+		config.logpid_flag = 1;
+	}
+	if (fparse(config.logaccess, "logaccess", config.file,
+	    sizeof(config.logaccess)) == -1) {
+		config.logaccess_flag = 0;
+	} else {
+		config.logaccess_flag = 1;
+		strlcpy(logn, config.logaccess, sizeof(logn));
+	}
 	if (fparse(config.user, "user", config.file, sizeof(config.user))
 	    == -1)
 		strlcpy(config.user, "0", sizeof(config.user));
@@ -541,8 +547,6 @@ main(int argc, char *argv[])
 		else
 			config.bsdauth = 0;
 	}
-#else
-	config.bsdauth = 0;
 #endif
 	if (fparse(config.sslportc, "sslport", config.file,
 	    sizeof(config.sslportc)) == -1)
@@ -861,6 +865,11 @@ main(int argc, char *argv[])
 	signal(SIGQUIT, sig_handler);
 	signal(SIGALRM, sig_handler);
 
+	/*
+	 * open syslog
+	 */
+	openlog("nhttpd", LOG_PID | LOG_NDELAY, LOG_DAEMON);
+
 	/*
 	 * daemonize
 	 */
@@ -881,12 +890,13 @@ main(int argc, char *argv[])
 	close(1);
 	close(2);
 	if (open("/dev/null", O_RDWR) == -1) {
-		flogd(config.logserver, "[error] open: %s\n", strerror(errno));
+		syslog(LOG_ERR, "open: %s", strerror(errno));
 		exit(1);
 	}
 	dup(0);
 	dup(0);
 
+#ifdef __OpenBSD__
         /*
          * basic authentication via bsd authentication framework
          */
@@ -908,14 +918,14 @@ main(int argc, char *argv[])
 		}
 		close(fdbsdauth[1]);
 	}
+#endif
 
 	/*
 	 * chroot to serverroot directory
 	 */
 	if (opt_r) {
 		if (chroot(config.serverroot) == -1) {
-			flogd(config.logserver, "[error] chroot: %s\n",
-			    strerror(errno));
+			syslog(LOG_ERR, "chroot: %s", strerror(errno));
 			exit(1);
 		}
 		strcuti(config.file, config.file, strlen(config.serverroot),
@@ -927,51 +937,49 @@ main(int argc, char *argv[])
 	 */
 	if (config.user[0] != '0') {
 		if (setgid(pwd->pw_gid) == -1) {
-			flogd(config.logserver, "[error] setgid: %s\n",
-			    strerror(errno));
+			syslog(LOG_ERR, "setgid: %s", strerror(errno));
 			exit(1);
 		}
 		if (setuid(pwd->pw_uid) == -1) {
-			flogd(config.logserver, "[error] setuid: %s\n",
-			    strerror(errno));
+			syslog(LOG_ERR, "setuid: %s", strerror(errno));
 			exit(1);
 		}
 	}
-	/* dont run as root */
+	/* don't run as root */
 	if (getuid() == 0) {
-		flogd(config.logserver,
-		    "[error] we dont run as root, choose another user\n");
+		syslog(LOG_ERR,
+		    "we don't run as root, choose another user");
 		exit(1);
 	}
 
 	/*
 	 * PID file creation
 	 */
-	if ((file = fopen(config.logpid, "w")) != NULL) {
-		fclose(file);
-		flog(config.logpid, "%d\n", ppid);
-	} else {
-		flogd(config.logserver, "[error] fopen: %s: %s\n",
-		    config.logpid, strerror(errno));
-		exit(1);
+	if (config.logpid_flag) {
+		if ((file = fopen(config.logpid, "w")) != NULL) {
+			fclose(file);
+			flog(config.logpid, "%d\n", ppid);
+		} else {
+			syslog(LOG_ERR, "fopen: %s: %s",
+			    config.logpid, strerror(errno));
+			exit(1);
+		}
 	}
 
 	/*
 	 * nostromo ready
 	 */
-	flogd(config.logserver, "[info] nhttpd started\n");
+	syslog(LOG_INFO, "started");
 	if (config.ssl)
-		flogd(config.logserver, "[info] SSL enabled on port %d\n",
-		    config.sslport);
+		syslog(LOG_INFO, "SSL enabled on port %d", config.sslport);
 	if (opt_r)
-		flogd(config.logserver, "[info] chroot to %s\n",
-		    config.serverroot);
+		syslog(LOG_INFO, "chroot to %s", config.serverroot);
 	if (opt_4 && opt_6)
-		flogd(config.logserver, "[info] IPv4 and IPv6 enabled\n");
+		syslog(LOG_INFO, "IPv4 and IPv6 enabled");
 	if (!opt_4 && opt_6)
-		flogd(config.logserver, "[info] IPv6 only enabled\n");
+		syslog(LOG_INFO, "IPv6 only enabled");
 	if (debug)
-		flogd(config.logserver, "[info] debug mode enabled\n");
+		syslog(LOG_INFO, "debug mode enabled");
 
 	/*
 	 * main loop
@@ -990,8 +998,7 @@ main(int argc, char *argv[])
 				continue;
 			}
 			/* EFAULT, EBADF, and EINVAL are not acceptable */
-			flogd(config.logserver, "[fatal] select: %s\n",
-			    strerror(errno));
+			syslog(LOG_ERR, "select: %s", strerror(errno));
 			break;
 		}
 
@@ -1017,8 +1024,8 @@ main(int argc, char *argv[])
 				    sdnow != sdlis3 && sdnow != sdlis4 &&
 				    c[sdnow].pfdo == 0 &&
 				    (time(&tnow) - c[sdnow].to) > TON) {
-					sys_log(config.logserver, debug,
-					"main: socket closed by us: timeout\n");
+					sys_log(debug,
+					"main: socket closed by us: timeout");
 					goto quit;
 				}
 				continue;
@@ -1329,7 +1336,7 @@ main(int argc, char *argv[])
 	 * nostromo shutdown
 	 */
 	munmap(mimes, mimes_size);
-	flogd(config.logserver, "[info] nhttpd stopped\n");
+	syslog(LOG_INFO, "stopped");
 	kill(0, SIGTERM);	/* terminate all childs */
 
 	return (0);
