@@ -51,8 +51,10 @@ struct header *	http_header(const char *, const char *, const int, const int,
 int		sys_mime(char *, const int, const char *, const int,
 		    const char *);
 int		sys_access_auth(const char *, const char *);
+#ifdef __OpenBSD__
 int		sys_access_bsdauth(const char *, const char *);
 void		sys_daemon_bsdauth(void);
+#endif
 int		sys_read(const int, char *, const int);
 int		sys_read_a(const int, char *, const int);
 int		sys_read_ssl(SSL *, char *, const int);
@@ -61,7 +63,7 @@ int		sys_write_a(const int, const char *, const int);
 int		sys_write_ssl(SSL *, const char *, const int);
 int		sys_resetnonblock(const int);
 int		sys_close_except(const int);
-int		sys_log(const char *, const int, const char *, ...);
+void		sys_log(const int, const char *, ...);
 int		sys_compar(const void *, const void *);
 char *		sys_date(struct tm *);
 char *		sys_benv(const char *, ...);
