@@ -24,9 +24,11 @@
 #include <errno.h>
 #include <fcntl.h>
 #include <openssl/ssl.h>
+#include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <syslog.h>
 #include <time.h>
 #include <unistd.h>
 #ifdef __OpenBSD__
@@ -180,7 +182,7 @@ sys_access_auth(const char *clientuser, const char *clientpw)
 
 	return (r);
 }
-
+#ifdef __OpenBSD__
 /*
  * sys_access_bsdauth()
  *	basic authentication over the bsd authentication framework
@@ -233,15 +235,14 @@ sys_daemon_bsdauth(void)
 			continue;
 		if (sys_read(fdbsdauth[1], clientpw, sizeof(clientpw)) < 1)
 			continue;
-#ifdef __OpenBSD__
 		r = auth_userokay(clientuser, NULL, NULL, clientpw);
-#endif
 		if (r > 0)
 			sys_write(fdbsdauth[1], "ok", 2);
 		else
 			sys_write(fdbsdauth[1], "nok", 3);
 	}
 }
+#endif
 
 /*
  * sys_read()
@@ -261,20 +262,18 @@ sys_read(const int sfd, char *buf, const int len)
 		/* handle errors */
 		if (r == -1) {
 			if (errno == EINTR) {
-				sys_log(config.logserver, debug,
-				    "sys_read: EINTR\n");
+				sys_log(debug, "sys_read: EINTR");
 				usleep(1);
 				continue;
 			}
-			flogd(config.logserver, "[error] sys_read: %s\n",
-			    strerror(errno));
+			syslog(LOG_ERR, "sys_read: %s", strerror(errno));
 			break;
 		}
 
 		/* descriptor closed by remote */
 		if (r == 0) {
-			sys_log(config.logserver, debug,
-			    "sys_read: descriptor closed by remote: %d\n", r);
+			sys_log(debug,
+			    "sys_read: descriptor closed by remote: %d", r);
 			break;
 		}
 
@@ -306,26 +305,24 @@ sys_read_a(const int sfd, char *buf, const int len)
 		/* handle errors */
 		if (r == -1) {
 			if (errno == EINTR) {
-				sys_log(config.logserver, debug,
-				    "sys_read_a: EINTR\n");
+				sys_log(debug, "sys_read_a: EINTR");
 				usleep(1);
 				continue;
 			}
 			if (errno == EAGAIN) {
-				sys_log(config.logserver, debug,
-				    "sys_read_a: EAGAIN: %d\n", got);
+				sys_log(debug, "sys_read_a: EAGAIN: %d", got);
 				return (got);
 			}
 			if (errno != ECONNRESET)
-				flogd(config.logserver, "[error] sys_read_a: "
-				    "%s\n", strerror(errno));
+				syslog(LOG_ERR, "sys_read_a: %s",
+				    strerror(errno));
 			return (r);
 		}
 
 		/* socket closed by remote */
 		if (r == 0) {
-			sys_log(config.logserver, debug,
-			    "sys_read_a: socket closed by remote: %d\n", got);
+			sys_log(debug,
+			    "sys_read_a: socket closed by remote: %d", got);
 			return (got);
 		}
 
@@ -361,16 +358,16 @@ sys_read_ssl(SSL *ssl, char *buf, const int len)
 			erro = SSL_get_error(ssl, r);
 
 			if (erro == SSL_ERROR_WANT_WRITE) {
-				sys_log(config.logserver, debug,
-				    "sys_read_ssl: WANT_WRITE: %d\n", got);
+				sys_log(debug, "sys_read_ssl: WANT_WRITE: %d",
+				    got);
 				return (got);
 			}
 			if (erro == SSL_ERROR_WANT_READ) {
-				sys_log(config.logserver, debug,
-				    "sys_read_ssl: WANT_READ: %d\n", got);
+				sys_log(debug, "sys_read_ssl: WANT_READ: %d",
+				    got);
 				return (got);
 			}
-			flog(config.logserver, "[error] sys_read_ssl\n");
+			syslog(LOG_ERR, "sys_read_ssl");
 			return (r);
 		}
 
@@ -410,19 +407,16 @@ sys_write(const int sfd, const char *buf, const int len)
 		/* handle errors */
 		if (r == -1) {
 			if (errno == EINTR) {
-				sys_log(config.logserver, debug,
-				    "sys_write: EINTR\n");
+				sys_log(debug, "sys_write: EINTR");
 				usleep(1);
 				continue;
 			}
 			if (errno == EAGAIN) {
-				sys_log(config.logserver, debug,
-				    "sys_write: EAGAIN: %d\n", sent);
+				sys_log(debug, "sys_write: EAGAIN: %d", sent);
 				usleep(1);
 				continue;
 			}
-			flogd(config.logserver, "[error] sys_write: %s\n",
-			    strerror(errno));
+			syslog(LOG_ERR, "sys_write: %s", strerror(errno));
 			return (r);
 		}
 
@@ -458,19 +452,17 @@ sys_write_a(const int sfd, const char *buf, const int len)
 		/* handle errors */
 		if (r == -1) {
 			if (errno == EINTR) {
-				sys_log(config.logserver, debug,
-				    "sys_write_a: EINTR\n");
+				sys_log(debug, "sys_write_a: EINTR");
 				usleep(1);
 				continue;
 			}
 			if (errno == EAGAIN) {
-				sys_log(config.logserver, debug,
-				    "sys_write_a: EAGAIN: %d\n", sent);
+				sys_log(debug, "sys_write_a: EAGAIN: %d", sent);
 				return (sent);
 			}
 			if (errno != EPIPE)
-				flogd(config.logserver, "[error] sys_write_a: "
-				    "%s\n", strerror(errno));
+				syslog(LOG_ERR, "sys_write_a: %s",
+				    strerror(errno));
 			return (r);
 		}
 
@@ -506,16 +498,16 @@ sys_write_ssl(SSL *ssl, const char *buf, const int len)
 			erro = SSL_get_error(ssl, r);
 
 			if (erro == SSL_ERROR_WANT_WRITE) {
-				sys_log(config.logserver, debug,
-				    "sys_write_ssl: WANT_WRITE: %d\n", sent);
+				sys_log(debug, "sys_write_ssl: WANT_WRITE: %d",
+				    sent);
 				return (sent);
 			}
 			if (erro == SSL_ERROR_WANT_READ) {
-				sys_log(config.logserver, debug,
-				    "sys_write_ssl: WANT_READ: %d\n", sent);
+				sys_log(debug, "sys_write_ssl: WANT_READ: %d",
+				    sent);
 				return (sent);
 			}
-			flogd(config.logserver, "[error] sys_write_ssl\n");
+			syslog(LOG_ERR, "sys_write_ssl");
 			return (r);
 		}
 
@@ -584,38 +576,14 @@ sys_close_except(const int fd)
 
 /* sys_log()
  *	debug logging
- * Return:
- *	0 = success, -1 = failed
- *
  */
-int
-sys_log(const char *file, const int debug, const char *string, ...)
+void
+sys_log(const int debug, const char *string, ...)
 {
-	FILE		*sfile;
-	char		*d;
-	va_list		ap;
-	time_t		tnow;
-	struct tm	*t;
-
 	if (!debug)
-		return (0);
+		return;
 
-	if ((sfile = fopen(file, "a")) == NULL)
-		return (-1);
-
-	time(&tnow);
-	t = localtime(&tnow);
-	d = asctime(t);
-	d[strlen(d) - 1] = '\0';
-	fprintf(sfile, "[%s] [debug] ", d);
-
-	va_start(ap, string);
-	vfprintf(sfile, string, ap);
-	va_end(ap);
-
-	fclose(sfile);
-
-	return (0);
+	syslog(LOG_DEBUG, "%s", string);
 }
 
 /*
